<h1 align="center">
  phidata
</h1>
<p align="center">
    <em>Build data products as code</em>
</p>
<p align="center">
<a href="https://python.org/pypi/phidata" target="_blank">
    <img src="https://img.shields.io/pypi/v/phidata?color=blue&label=version" alt="version">
</a>
<a href="https://github.com/phidatahq/phidata" target="_blank">
    <img src="https://img.shields.io/badge/python->=3.7-blue" alt="pythonversion">
</a>
<a href="https://github.com/phidatahq/phidata" target="_blank">
    <img src="https://pepy.tech/badge/phidata" alt="downloads">
</a>
<a href="https://github.com/phidatahq/phidata/actions/workflows/build.yml" target="_blank">
    <img src="https://github.com/phidatahq/phidata/actions/workflows/build.yml/badge.svg?branch=main" alt="build-status">
</a>
<a href="https://github.com/phidatahq/phidata/actions/workflows/test.yml" target="_blank">
    <img src="https://github.com/phidatahq/phidata/actions/workflows/test.yml/badge.svg?branch=main" alt="test-status">
</a>
</p>

---

**Website**: <a href="https://phidata.com" target="_blank">phidata.com</a>

**Documentation**: <a href="https://docs.phidata.com" target="_blank">https://docs.phidata.com</a>

**Chat**: <a href="https://discord.gg/4MtYHHrgA8" target="_blank">Discord link</a>

---

